@@ -56,6 +56,18 @@ class SmartMeterThing(Thing):
                          'readOnly': True,
                      }))
 
+        self.time_last_frame_processed = Value("")
+        self.add_property(
+            Property(self,
+                     'time_last_frame_processed',
+                     self.time_last_frame_processed,
+                     metadata={
+                         'title': 'time valued measured',
+                         "type": "str",
+                         'description': 'The time values measured [iso datetime]',
+                         'readOnly': True,
+                     }))
+
 
         self.ioloop = tornado.ioloop.IOLoop.current()
         self.meter.add_listener(self.on_value_changed)
@@ -67,6 +79,7 @@ class SmartMeterThing(Thing):
         self.current_power.notify_of_external_update(self.meter.current_power)
         self.consumed_power_total.notify_of_external_update(self.meter.consumed_power_total)
         self.produced_power_total.notify_of_external_update(self.meter.produced_power_total)
+        self.time_last_frame_processed.notify_of_external_update(self.meter.time_last_frame_processed.strftime("%Y-%m-%dT%H:%M:%S"))
 
 
 def run_server(description: str, port: int, sport: str):
